@@ -74,8 +74,8 @@ read.surv<-function(m,id,npar,clusters,start.time,max.time,model="aalen",silent=
     status <- m[, 1][, "status"]
   }
   else if (attr(m[, 1], "type") == "counting") {
-    if ((is.null(id)==TRUE) && (silent==0)) 
-      cat("For counting process data, with multiple records the id variable must be set to get correct robust standard errors and simulations\n");
+###    if ((is.null(id)==TRUE) && (silent==0)) 
+###      cat("For counting process data, with multiple records the id variable must be set to get correct robust standard errors and simulations\n");
     time <- m[, 1][, 1];time2 <- m[, 1][, 2];status <- m[, 1][, 3];
   }
   else { stop("only right-censored or counting processes data") }
