@@ -10,19 +10,22 @@ robust=1,theta=NULL,theta.des=NULL,var.link=0,step=0.5,notaylor=0)
  beta.fixed <- attr(margsurv,"beta.fixed")
  if (is.null(beta.fixed)) beta.fixed <- 1; 
  ldata<-aalen.des(formula,data=data,model="cox.aalen");
- id <- attr(margsurv,"id"); clusters <- attr(margsurv,"cluster")
+ id <- attr(margsurv,"id"); mclusters <- attr(margsurv,"cluster")
  X<-ldata$X; time<-ldata$time2; Z<-ldata$Z;  status<-ldata$status;
- if (nrow(X)!=length(clusters)) 
-stop("Length of margsurv data not consistent with nrow of data\n"); 
  time2 <- attr(margsurv,"stop"); start <- attr(margsurv,"start")
  antpers<-nrow(X);
  if (is.null(Z)==TRUE) {npar<-TRUE; semi<-0;}  else { Z<-as.matrix(Z); npar<-FALSE; semi<-1;}
-  if (npar==TRUE) {Z<-matrix(0,antpers,1); pz<-1; fixed<-0;} else {fixed<-1;pz<-ncol(Z);}
-  px<-ncol(X);
+ if (npar==TRUE) {Z<-matrix(0,antpers,1); pz<-1; fixed<-0;} else {fixed<-1;pz<-ncol(Z);}
+ px<-ncol(X);
+
+  if (is.null(clusters))  clusters <- mclusters else if (sum(abs(clusters-mclusters))>0) 
+	  cat("Warning: Clusters for marginal model different than those specified for two.stage\n"); 
 
   if (!is.null(attr(margsurv,"max.clust")))
   if (attr(margsurv,"max.clust")< attr(margsurv,"orig.max.clust")) 
-	  cat("Probably want to estimate marginal model with max.clust=NULL\n"); 
+	  cat("Warning: Probably want to estimate marginal model with max.clust=NULL\n"); 
+
+ if (nrow(X)!=length(clusters)) stop("Length of Marginal survival data not consistent with cluster length\n"); 
 
   out.clust <- cluster.index(clusters);  
   maxclust <- out.clust$maxclust 
@@ -34,7 +37,7 @@ stop("Length of margsurv data not consistent with nrow of data\n");
 
   if (npar==TRUE) RR <-  rep(1,antpers); 
   if (npar==FALSE) RR <- exp(Z %*% margsurv$gamma); 
-  if ((attr(margsurv,"residuals")!=2) || (lefttrunk==1)) {### compute cum hazards in time point infty; 
+  if ((attr(margsurv,"residuals")!=2) || (lefttrunk==1)) { ### compute cum hazards in time point infty; 
 	  nn <- nrow(margsurv$cum) 
 	  cum <- Cpred(margsurv$cum,time2)[,-1]
 	  if (npar==TRUE) cumhaz <- apply(cum*X,1,sum)
@@ -80,28 +83,6 @@ stop("Length of margsurv data not consistent with nrow of data\n");
   if (length(theta)!=ptheta) theta<-rep(theta[1],ptheta); 
   theta.score<-rep(0,ptheta);Stheta<-var.theta<-matrix(0,ptheta,ptheta); 
 
-  out.clust <- cluster.index(clusters,index.type=TRUE);  
-  maxclust <- out.clust$maxclust 
-  antclust <- out.clust$antclust
-  idiclust <- out.clust$idclust
-
-###  nclust <- .C("nclusters",
-###		as.integer(antpers), as.integer(clusters), as.integer(rep(0,antpers)), 
-###		as.integer(0), as.integer(0), package="timereg")
-###  clustud <- .C("clusterindex",as.integer(clusters),
-###		as.integer(antclust),as.integer(antpers),
-###                as.integer(rep(0,antclust*maxclust)),as.integer(rep(0,antclust)),
-###	  package="timereg")
-###idiclust <- matrix(clustud[[4]],antclust,maxclust)
-
-###  cluster.size<-as.vector(table(clusters));
-###  maxclust<-max(cluster.size)
-###  idiclust<-matrix(0,antclust,maxclust); 
-###  cs<- rep(1,antclust)
-###  for (i in 1:antpers) { 
-###      idiclust[clusters[i]+1,cs[clusters[i]+1]]<-i-1;
-###      cs[clusters[i]+1]<- cs[clusters[i]+1]+1; 
-###  } 
   if (maxclust==1) stop("No clusters !, maxclust size=1\n"); 
   ## }}}
 
@@ -213,21 +194,22 @@ summary.two.stage<-function (object,digits = 3,...) { ## {{{
 } ## }}}
 
 print.two.stage <- function (x,digits = 3,...) { ## {{{
-  if (!(inherits(x, 'two.stage') )) stop("Must be a Two-Stage object")
-  cat(" Two-stage estimation for Clayton-Oakes-Glidden  model\n"); 
-  cat(" Marginals of Cox-Aalen form, dependence by variance of Gamma distribution\n\n");  
-  object <- x; rm(x);
-  
-  cat(" Nonparametric components : "); 
-  cat(colnames(object$cum)[-1]); cat("   \n");  
-  if (!is.null(object$gamma)) {
-    cat(" Parametric components :  "); cat(rownames(object$gamma)); 
-    cat("   \n");
-  } 
-  cat("   \n");  
-
-  cat(" Call: \n");
-  print(attr(object,'Call'))
+	summary.two.stage(x,digits=digits,...)
+###  if (!(inherits(x, 'two.stage') )) stop("Must be a Two-Stage object")
+###  cat(" Two-stage estimation for Clayton-Oakes-Glidden  model\n"); 
+###  cat(" Marginals of Cox-Aalen form, dependence by variance of Gamma distribution\n\n");  
+###  object <- x; rm(x);
+###  
+###  cat(" Nonparametric components : "); 
+###  cat(colnames(object$cum)[-1]); cat("   \n");  
+###  if (!is.null(object$gamma)) {
+###    cat(" Parametric components :  "); cat(rownames(object$gamma)); 
+###    cat("   \n");
+###  } 
+###  cat("   \n");  
+###
+###  cat(" Call: \n");
+###  print(attr(object,'Call'))
 } ## }}}
 
 coef.two.stage<-function(object,digits=3,d2logl=1,...) {
